pub fn rtc_calib_version() -> u8Available on crate feature
unstable only.Expand description
Get version of RTC calibration block
See: https://github.com/espressif/esp-idf/blob/be06a6f/components/efuse/esp32h2/esp_efuse_rtc_calib.c#L20 //esp_efuse_rtc_calib_get_ver
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.